<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
<!ENTITY ciqc "urn:oasis:names:tc:ciq:ct:3">
<!ENTITY ciqa "urn:oasis:names:tc:ciq:xal:3">
<!ENTITY ciqn "urn:oasis:names:tc:ciq:xnl:3">
<!ENTITY ciqna "urn:oasis:names:tc:ciq:xnal:3">
<!ENTITY ciqp "urn:oasis:names:tc:ciq:xpil:3">
<!ENTITY ciqr "urn:oasis:names:tc:ciq:xprl:3">
]>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.ascc.net/xml/schematron"
                xmlns:ccs="urn:x-Crane:ss:Crane-Constraints2Schematron"
                exclude-result-prefixes="ccs"
                version="1.0">
<!--
     Support for a contrived implementation of CIQ meta data, in support
     of the OASIS Code List TC's Schematron Methodology for Code List and Value Validation.

     This fragment determines the names of meta data information items
     related to code list information items.

  $Id: CIQ-Metadata.xsl,v 1.3 2007/09/018 00:10:14 Ram Kumar Exp $

OASIS Customer Information Quality (CIQ) Technical Committee
CIQ Specifications v3.0
Copyright (C) OASIS Open (2007). All Rights Reserved.

This document and translations of it may be copied and furnished to others, and
derivative works that comment on or otherwise explain it or assist in its
implementation may be prepared, copied, published and distributed, in whole or
in part, without restriction of any kind, provided that the above copyright
notice and this paragraph are included on all such copies and derivative works.
However, this document itself may not be modified in any way, such as by
removing the copyright notice or references to OASIS, except as needed for the
purpose of developing OASIS specifications, in which case the procedures for
copyrights defined in the OASIS Intellectual Property Rights document must be
followed, or as required to translate it into languages other than English.

The limited permissions granted above are perpetual and will not be revoked by
OASIS or its successors or assigns.

This document and the information contained herein is provided on an "AS IS"
basis and OASIS DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, INCLUDING BUT NOT
LIMITED TO ANY WARRANTY THAT THE USE OF THE INFORMATION HEREIN WILL NOT
INFRINGE ANY RIGHTS OR ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR
A PARTICULAR PURPOSE.

-->

<!--========================================================================-->
<!--for a given information item, engage the checking of various metadata
    properties supported by the external code list implementation-->
<!--
     parameter $item - the normalized @item attribute from the association
                       (for namespace-safe reasons, $item should not be used)
     parameter $list - <ValueList> node from the association
     parameter $attr - true/false flag that the addressed item is an attribute
     parameter $name - the local name of the addressed item (without prefix)
     parameter $ns   - the namespace of the addressed item (not the prefix)
     parameter $spec - the @item specification node from the association
     current node    - the context information item from the input document
-->
<!-- calling check-list-property for every possible meta data item
     arguments:
       address:  XPath string to find the meta data
       property: Meta data abstract identifier string
       list:     pass-through of passed parameter
-->

<xsl:template name="ccs:document-model-metadata">
  <xsl:param name="item"/>
  <xsl:param name="list"/>
  <xsl:param name="attr"/>
  <xsl:param name="name"/>
  <xsl:param name="ns"/>
  <xsl:param name="spec"/>
  
  <xsl:choose>
  <!-- *********************************************************************************
                              Metadata attributes in CIQ xNL Schema 
  *    ********************************************************************************** -->
  
    <xsl:when test="$attr and $ns='&ciqn;' and $name='PartyNameIDType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PartyNameIDTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PartyNameIDTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PartyNameIDTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PartyNameIDTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqn;' and $name='JointNameConnector'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'JointNameConnectorTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'JointNameConnectorTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'JointNameConnectorTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'JointNameConnectorTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
        
	<xsl:when test="$attr and $ns='&ciqn;' and $name='DataQualityType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqn;' and $name='Status'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqn;' and $name='Type'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when> 
    
    <xsl:when test="$attr and $ns='&ciqn;' and $name='PersonIDType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PersonIDTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PersonIDTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PersonIDTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'PersonIDTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when> 
    
    <xsl:when test="$attr and $ns='&ciqn;' and $name='ElementType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'ElementTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'ElementTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>PartyNameIDType
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'ElementTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'ElementTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>      
    
    <xsl:when test="$attr and $ns='&ciqn;' and $name='OrganisationIDType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'OrganisationIDTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'OrganisationIDTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'OrganisationIDTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqn;'"/>
        <xsl:with-param name="metaname" select="'OrganisationIDTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <!-- *********************************************************************************
                              Metadata attributes in CIQ xAL Schema 
  *    ********************************************************************************** -->
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='Type'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when> 
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='Status'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='Usage'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='AddressIDType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'AddressIDTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'AddressIDTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'AddressIDTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'AddressIDTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='DataQualityType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='NameType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='NameCode'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameCodeTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameCodeTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameCodeTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'NameCodeTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='Meridian'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'MeridianTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'MeridianTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'MeridianTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'MeridianTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='Datum'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DatumTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DatumTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DatumTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DatumTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='Projection'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'ProjectionTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'ProjectionTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'ProjectionTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'ProjectionTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>
    
    <xsl:when test="$attr and $ns='&ciqa;' and $name='Direction'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DirectionTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DirectionTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DirectionTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqa;'"/>
        <xsl:with-param name="metaname" select="'DirectionTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>    
    
    <!-- *********************************************************************************
                              Metadata attributes in CIQ xNAL Schema 
          ********************************************************************************* -->
    <xsl:when test="$attr and $ns='&ciqna;' and $name='RecordIDType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqna;'"/>
        <xsl:with-param name="metaname" select="'RecordIDTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqna;'"/>
        <xsl:with-param name="metaname" select="'RecordIDTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqna;'"/>
        <xsl:with-param name="metaname" select="'RecordIDTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqna;'"/>
        <xsl:with-param name="metaname" select="'RecordIDTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>
    
    <xsl:when test="$attr and $ns='&ciqna;' and $name='DataQualityType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>      
    
    <xsl:when test="$attr and $ns='&ciqna;' and $name='Status'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>            
    
    <xsl:when test="$attr and $ns='&ciqna;' and $name='Type'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when> 
    
    <!-- *********************************************************************************
                              Metadata attributes in CIQ xPIL Schema 
          ********************************************************************************* -->    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='PartyType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='PartyIDType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyIDTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyIDTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyIDTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartyIDTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='DataQualityType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'DataQualityTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>      
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Status'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'StatusTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Type'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'TypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>     
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='OwnershipType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'OwnershipTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'OwnershipTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'OwnershipTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'OwnershipTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>     
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='CommunicationMediaType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CommunicationMediaTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CommunicationMediaTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CommunicationMediaTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CommunicationMediaTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>     
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Usage'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'UsageTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='RelationshipWithPerson'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithPersonTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithPersonTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithPersonTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithPersonTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='RelationshipWithOrganisation'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithOrganisationTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithOrganisationTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithOrganisationTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'RelationshipWithOrganisationTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when> 
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='CurrencyCode'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CurrencyCodeTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CurrencyCodeTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CurrencyCodeTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CurrencyCodeTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Source'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SourceTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SourceTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SourceTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SourceTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Category'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'CategoryTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'CategoryTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'CategoryTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqc;'"/>
        <xsl:with-param name="metaname" select="'CategoryTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Nature'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'NatureTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'NatureTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'NatureTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'NatureTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Industry'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='IndustryCode'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryCodeTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryCodeTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryCodeTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'IndustryCodeTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>            
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='PhysicalStatus'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PhysicalStatusTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PhysicalStatusTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PhysicalStatusTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PhysicalStatusTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='MaritalStatus'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'MaritalStatusTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'MaritalStatusTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'MaritalStatusTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'MaritalStatusTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>    
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Ethnicity'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'EthnicityTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'EthnicityTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'EthnicityTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'EthnicityTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>    
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Gender'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'GenderTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'GenderTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'GenderTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'GenderTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>    
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Religion'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReligionTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReligionTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReligionTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReligionTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>    
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Speak'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SpeakTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SpeakTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SpeakTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'SpeakTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>    
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Read'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReadTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReadTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReadTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'ReadTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Write'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'WriteTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'WriteTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'WriteTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'WriteTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Understand'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnderstandTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnderstandTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnderstandTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnderstandTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Preference'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PreferenceTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PreferenceTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PreferenceTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PreferenceTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='BloodGroup'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'BloodGroupTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'BloodGroupTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'BloodGroupTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'BloodGroupTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='UnitType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnitTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnitTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnitTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'UnitTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>  
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='PartType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'PartTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>      
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Location'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'LocationTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'LocationTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'LocationTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'LocationTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>      
    
    <xsl:when test="$attr and $ns='&ciqp;' and $name='Cause'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CauseTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CauseTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CauseTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqp;'"/>
        <xsl:with-param name="metaname" select="'CauseTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>      
    
    <!-- *********************************************************************************
                              Metadata attributes in CIQ xPRL Schema 
          ********************************************************************************* -->    
    <xsl:when test="$attr and $ns='&ciqr;' and $name='RelationshipType'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqr;' and $name='RelationshipStatus'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStatusTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStatusTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStatusTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStatusTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqr;' and $name='RelationshipStartReason'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStartReasonTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStartReasonTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStartReasonTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipStartReasonTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
     <xsl:when test="$attr and $ns='&ciqr;' and $name='RelationshipEndReason'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipEndReasonTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipEndReasonTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipEndReasonTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'RelationshipEndReasonTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqr;' and $name='PrimaryPartyRelationshipRole'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'PrimaryPartyRelationshipRoleTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'PrimaryPartyRelationshipRoleTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'PrimaryPartyRelationshipRoleTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'PrimaryPartyRelationshipRoleTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    
    <xsl:when test="$attr and $ns='&ciqr;' and $name='SecondaryPartyRelationshipRole'">
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'SecondaryPartyRelationshipRoleTypeRef'"/>
        <xsl:with-param name="property" select="'ShortName'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'SecondaryPartyRelationshipRoleTypeVer'"/>
        <xsl:with-param name="property" select="'Version'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property"> 
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'SecondaryPartyRelationshipRoleTypeURI'"/>
        <xsl:with-param name="property" select="'CanonicalUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
      <xsl:call-template name="ccs:check-list-property">
        <xsl:with-param name="metans"   select="'&ciqr;'"/>
        <xsl:with-param name="metaname" select="'SecondaryPartyRelationshipRoleTypeVerURI'"/>
        <xsl:with-param name="property" select="'CanonicalVersionUri'"/>
        <xsl:with-param name="list"     select="$list"/>
        <xsl:with-param name="itemattr" select="$attr"/>
        <xsl:with-param name="metaattr" select="true()"/>
      </xsl:call-template>
    </xsl:when>        
    <xsl:otherwise>
      <!--there are no other elements or attributes based on code lists-->
    </xsl:otherwise>
  </xsl:choose>

</xsl:template>

</xsl:stylesheet>
